Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(324)

Unified Diff: media/cast/net/cast_transport_config.h

Issue 1534273002: Switch to standard integer types in media/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/cast/net/cast_transport_config.h
diff --git a/media/cast/net/cast_transport_config.h b/media/cast/net/cast_transport_config.h
index 7cdeec9dd2370e3eb7630bcdd91bbb72bd788ec0..eb3cac6ac87e63d62ff8d69e07ee9c7cb68069d1 100644
--- a/media/cast/net/cast_transport_config.h
+++ b/media/cast/net/cast_transport_config.h
@@ -7,7 +7,6 @@
#include <string>
-#include "base/basictypes.h"
#include "base/callback.h"
#include "base/stl_util.h"
#include "media/cast/net/cast_transport_defines.h"
@@ -31,10 +30,10 @@ struct CastTransportRtpConfig {
~CastTransportRtpConfig();
// Identifier refering to this sender.
- uint32 ssrc;
+ uint32_t ssrc;
// Identifier for incoming RTCP traffic.
- uint32 feedback_ssrc;
+ uint32_t feedback_ssrc;
// RTP payload type enum: Specifies the type/encoding of frame data.
int rtp_payload_type;
@@ -70,13 +69,13 @@ struct EncodedFrame {
EncodedFrame();
virtual ~EncodedFrame();
- // Convenience accessors to data as an array of uint8 elements.
- const uint8* bytes() const {
- return reinterpret_cast<uint8*>(string_as_array(
- const_cast<std::string*>(&data)));
+ // Convenience accessors to data as an array of uint8_t elements.
+ const uint8_t* bytes() const {
+ return reinterpret_cast<uint8_t*>(
+ string_as_array(const_cast<std::string*>(&data)));
}
- uint8* mutable_bytes() {
- return reinterpret_cast<uint8*>(string_as_array(&data));
+ uint8_t* mutable_bytes() {
+ return reinterpret_cast<uint8_t*>(string_as_array(&data));
}
// Copies all data members except |data| to |dest|.
@@ -88,19 +87,19 @@ struct EncodedFrame {
// The label associated with this frame. Implies an ordering relative to
// other frames in the same stream.
- uint32 frame_id;
+ uint32_t frame_id;
// The label associated with the frame upon which this frame depends. If
// this frame does not require any other frame in order to become decodable
// (e.g., key frames), |referenced_frame_id| must equal |frame_id|.
- uint32 referenced_frame_id;
+ uint32_t referenced_frame_id;
// The stream timestamp, on the timeline of the signal data. For example, RTP
// timestamps for audio are usually defined as the total number of audio
// samples encoded in all prior frames. A playback system uses this value to
// detect gaps in the stream, and otherwise stretch the signal to match
// playout targets.
- uint32 rtp_timestamp;
+ uint32_t rtp_timestamp;
// The common reference clock timestamp for this frame. This value originates
// from a sender and is used to provide lip synchronization between streams in
@@ -113,7 +112,7 @@ struct EncodedFrame {
// Playout delay for this and all future frames. Used by the Adaptive
// Playout delay extension. Zero means no change.
- uint16 new_playout_delay_ms;
+ uint16_t new_playout_delay_ms;
// The encoded signal data.
std::string data;
@@ -133,7 +132,7 @@ class PacketSender {
virtual bool SendPacket(PacketRef packet, const base::Closure& cb) = 0;
// Returns the number of bytes ever sent.
- virtual int64 GetBytesSent() = 0;
+ virtual int64_t GetBytesSent() = 0;
virtual ~PacketSender() {}
};
@@ -143,31 +142,31 @@ struct RtcpSenderInfo {
~RtcpSenderInfo();
// First three members are used for lipsync.
// First two members are used for rtt.
- uint32 ntp_seconds;
- uint32 ntp_fraction;
- uint32 rtp_timestamp;
- uint32 send_packet_count;
+ uint32_t ntp_seconds;
+ uint32_t ntp_fraction;
+ uint32_t rtp_timestamp;
+ uint32_t send_packet_count;
size_t send_octet_count;
};
struct RtcpReportBlock {
RtcpReportBlock();
~RtcpReportBlock();
- uint32 remote_ssrc; // SSRC of sender of this report.
- uint32 media_ssrc; // SSRC of the RTP packet sender.
- uint8 fraction_lost;
- uint32 cumulative_lost; // 24 bits valid.
- uint32 extended_high_sequence_number;
- uint32 jitter;
- uint32 last_sr;
- uint32 delay_since_last_sr;
+ uint32_t remote_ssrc; // SSRC of sender of this report.
+ uint32_t media_ssrc; // SSRC of the RTP packet sender.
+ uint8_t fraction_lost;
+ uint32_t cumulative_lost; // 24 bits valid.
+ uint32_t extended_high_sequence_number;
+ uint32_t jitter;
+ uint32_t last_sr;
+ uint32_t delay_since_last_sr;
};
struct RtcpDlrrReportBlock {
RtcpDlrrReportBlock();
~RtcpDlrrReportBlock();
- uint32 last_rr;
- uint32 delay_since_last_rr;
+ uint32_t last_rr;
+ uint32_t delay_since_last_rr;
};
inline bool operator==(RtcpSenderInfo lhs, RtcpSenderInfo rhs) {

Powered by Google App Engine
This is Rietveld 408576698